pub struct CNPostalAddress { /* private fields */ }CNPostalAddress only.Expand description
An immutable value object representing a postal address.
CNPostalAddress is thread safe.
See also Apple’s documentation
Implementations
Sourceimpl CNPostalAddress
impl CNPostalAddress
Sourcepub unsafe fn street(&self) -> Retained<NSString>
pub unsafe fn street(&self) -> Retained<NSString>
multi-street address is delimited with carriage returns “ \n”
pub unsafe fn subLocality(&self) -> Retained<NSString>
pub unsafe fn city(&self) -> Retained<NSString>
pub unsafe fn subAdministrativeArea(&self) -> Retained<NSString>
pub unsafe fn state(&self) -> Retained<NSString>
pub unsafe fn postalCode(&self) -> Retained<NSString>
pub unsafe fn country(&self) -> Retained<NSString>
pub unsafe fn ISOCountryCode(&self) -> Retained<NSString>
Sourcepub unsafe fn localizedStringForKey(key: &NSString) -> Retained<NSString>
pub unsafe fn localizedStringForKey(key: &NSString) -> Retained<NSString>
Returns a user displayable property name.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for CNPostalAddress
impl AsRef<AnyObject> for CNPostalAddress
Sourceimpl AsRef<CNPostalAddress> for CNMutablePostalAddress
Available on crate feature CNMutablePostalAddress only.
impl AsRef<CNPostalAddress> for CNMutablePostalAddress
CNMutablePostalAddress only.Sourcefn as_ref(&self) -> &CNPostalAddress
fn as_ref(&self) -> &CNPostalAddress
Sourceimpl AsRef<CNPostalAddress> for CNPostalAddress
impl AsRef<CNPostalAddress> for CNPostalAddress
Sourceimpl AsRef<NSObject> for CNPostalAddress
impl AsRef<NSObject> for CNPostalAddress
Sourceimpl Borrow<AnyObject> for CNPostalAddress
impl Borrow<AnyObject> for CNPostalAddress
Sourceimpl Borrow<CNPostalAddress> for CNMutablePostalAddress
Available on crate feature CNMutablePostalAddress only.
impl Borrow<CNPostalAddress> for CNMutablePostalAddress
CNMutablePostalAddress only.Sourcefn borrow(&self) -> &CNPostalAddress
fn borrow(&self) -> &CNPostalAddress
Sourceimpl Borrow<NSObject> for CNPostalAddress
impl Borrow<NSObject> for CNPostalAddress
Sourceimpl ClassType for CNPostalAddress
impl ClassType for CNPostalAddress
Sourceconst NAME: &'static str = "CNPostalAddress"
const NAME: &'static str = "CNPostalAddress"
Sourcetype ThreadKind = <<CNPostalAddress as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<CNPostalAddress as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for CNPostalAddress
impl CopyingHelper for CNPostalAddress
Sourcetype Result = CNPostalAddress
type Result = CNPostalAddress
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for CNPostalAddress
impl Debug for CNPostalAddress
Sourceimpl Deref for CNPostalAddress
impl Deref for CNPostalAddress
Sourceimpl Hash for CNPostalAddress
impl Hash for CNPostalAddress
Sourceimpl Message for CNPostalAddress
impl Message for CNPostalAddress
Sourceimpl MutableCopyingHelper for CNPostalAddress
Available on crate feature CNMutablePostalAddress only.
impl MutableCopyingHelper for CNPostalAddress
CNMutablePostalAddress only.Sourcetype Result = CNMutablePostalAddress
type Result = CNMutablePostalAddress
Self if the type has no
mutable counterpart. Read moreSourceimpl NSCopying for CNPostalAddress
impl NSCopying for CNPostalAddress
Sourceimpl NSMutableCopying for CNPostalAddress
impl NSMutableCopying for CNPostalAddress
Sourceimpl NSObjectProtocol for CNPostalAddress
impl NSObjectProtocol for CNPostalAddress
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref